@@ -179,6 +179,7 @@ samples.fitted <- array(NA, c(n.keep, n))
      
 ## Metropolis quantities
 accept <- c(0,0)
+accept.all <- c(0,0)
 proposal.sd.alpha <- 0.02 * alpha.max
 tau2.posterior.shape <- prior.tau2[1] + 0.5*(n-1)
 nu2.posterior.shape <- prior.nu2[1] + 0.5*n
@@ -191,6 +192,8 @@ nu2.posterior.shape <- prior.nu2[1] + 0.5*n
     if(sum(is.na(W))>0) stop("W has missing 'NA' values.", call.=FALSE)
     if(!is.numeric(W)) stop("W has non-numeric values.", call.=FALSE)
     if(!sum(names(table(W))==c(0,1))==2) stop("W has non-binary (zero and one) values.", call.=FALSE)
+    if(sum(W!=t(W))>0) stop("W is not symmetric.", call.=FALSE)
+    if(min(apply(W, 1, sum))==0) stop("W has some areas with no neighbours (one of the row sums equals zero).", call.=FALSE)    
 
 
 ## Ensure the W matrix is symmetric
@@ -267,8 +270,6 @@ det.Q <- sum(log(diag(chol.spam(Q))))
 
 #### Beta update quantities
 data.precision.beta <- t(X.standardised) %*% X.standardised
-data.var.beta <- solve(data.precision.beta)
-data.temp.beta <- data.var.beta %*% t(X.standardised)
 	if(length(prior.var.beta)==1)
 	{
 	prior.precision.beta <- 1 / prior.var.beta
@@ -298,13 +299,13 @@ data.temp.beta <- data.var.beta %*% t(X.standardised)
 		####################
 		## Sample from beta
 		####################
-		data.mean.beta <- data.temp.beta %*% (Y - phi - offset)
-		U <- chol((prior.precision.beta + data.precision.beta / nu2))
-		Uinv <- backsolve(U, diag(rep(1,p)))
-		fc.mean.beta <- Uinv %*% (t(Uinv) %*% (prior.precision.beta %*% prior.mean.beta + (data.precision.beta / nu2) %*% data.mean.beta))
-		beta <- fc.mean.beta + Uinv %*% rnorm(p)
-		     
-
+		fc.precision <- prior.precision.beta + data.precision.beta / nu2
+		fc.var <- solve(fc.precision)
+		beta.offset <- as.numeric(Y - offset - phi)
+		beta.offset2 <- t(X.standardised) %*% beta.offset / nu2 + prior.precision.beta %*% prior.mean.beta
+		fc.mean <- fc.var %*% beta.offset2
+		chol.var <- t(chol(fc.var))
+		beta <- fc.mean + chol.var %*% rnorm(p)  
 
 		##################
 		## Sample from nu2
@@ -396,7 +397,31 @@ data.temp.beta <- data.var.beta %*% t(X.standardised)
                }
 
     
-    
+		    ########################################
+		    ## Self tune the acceptance probabilties
+		    ########################################
+		    k <- j/100
+		        if(ceiling(k)==floor(k))
+		        {
+		        #### Determine the acceptance probabilities
+		        accept.alpha <- 100 * accept[1] / accept[2]
+		        accept.all <- accept.all + accept
+		        accept <- c(0,0)
+		    
+		        #### alpha tuning parameter
+		            if(accept.alpha > 50)
+		            {
+		            proposal.sd.alpha <- min(2 * proposal.sd.alpha, alpha.max/4)
+		            }else if(accept.alpha < 40)              
+		            {
+		            proposal.sd.alpha <- 0.5 * proposal.sd.alpha
+		            }else
+		            {
+		            }
+		    }else
+		    {   
+		    }
+		
           ################################       
           ## print progress to the console
           ################################
@@ -419,7 +444,7 @@ data.temp.beta <- data.var.beta %*% t(X.standardised)
 #### Summarise and save the results 
 ###################################
 ## Acceptance rates
-accept.alpha <- 100 * accept[1] / accept[2]
+accept.alpha <- 100 * accept.all[1] / accept.all[2]
 accept.final <- c(100, 100, 100, 100, accept.alpha)
 names(accept.final) <- c("beta", "phi", "nu2", "tau2", "alpha")
  
@@ -438,7 +463,7 @@ DIC <- 2 * median(samples.deviance) - deviance.fitted
 CPO <- rep(NA, n)
      for(j in 1:n)
      {
-     CPO[j] <- 1/median((1 / dnorm(Y[j], mean=samples.fitted[ ,j], sd=samples.nu2)))    
+     CPO[j] <- 1/median((1 / dnorm(Y[j], mean=samples.fitted[ ,j], sd=sqrt(samples.nu2))))    
      }
 LMPL <- sum(log(CPO))   
      
@@ -476,14 +501,14 @@ if(number.cts>0)
 #### Create a summary object
 samples.beta.orig <- mcmc(samples.beta.orig)
 summary.beta <- t(apply(samples.beta.orig, 2, quantile, c(0.5, 0.025, 0.975))) 
-summary.beta <- cbind(summary.beta, rep(n.keep, p), rep(100,p))
+summary.beta <- cbind(summary.beta, rep(n.keep, p), rep(100,p), effectiveSize(samples.beta.orig), geweke.diag(samples.beta.orig)$z)
 rownames(summary.beta) <- colnames(X)
-colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept")
+colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
 
 samples.alpha <- mcmc(samples.alpha)
 summary.alpha <- t(apply(samples.alpha, 2, quantile, c(0.5, 0.025, 0.975))) 
-summary.alpha <- cbind(summary.alpha, rep(n.keep, q), rep(accept.alpha,q))
-colnames(summary.alpha) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept")
+summary.alpha <- cbind(summary.alpha, rep(n.keep, q), rep(accept.alpha,q), effectiveSize(samples.alpha), geweke.diag(samples.alpha)$z)
+
 
 	if(!is.null(names(Z)))
  	{
@@ -500,19 +525,19 @@ colnames(summary.alpha) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept")
 
 
 
-summary.hyper <- array(NA, c(2 ,5))
+summary.hyper <- array(NA, c(2 ,7))
 summary.hyper[1, 1:3] <- quantile(samples.nu2, c(0.5, 0.025, 0.975))
-summary.hyper[1, 4:5] <- c(n.keep, 100)
+summary.hyper[1, 4:7] <- c(n.keep, 100, effectiveSize(samples.nu2), geweke.diag(samples.nu2)$z)
 summary.hyper[2, 1:3] <- quantile(samples.tau2, c(0.5, 0.025, 0.975))
-summary.hyper[2, 4:5] <- c(n.keep, 100)
+summary.hyper[2, 4:7] <- c(n.keep, 100, effectiveSize(samples.tau2), geweke.diag(samples.tau2)$z)
 
 summary.results <- rbind(summary.beta, summary.hyper, summary.alpha)
 alpha.min <- c(rep(NA, (p+2)), alpha.threshold)
 summary.results <- cbind(summary.results, alpha.min)
 rownames(summary.results)[(p+1):(p+2)] <- c("nu2", "tau2")
 summary.results[ , 1:3] <- round(summary.results[ , 1:3], 4)
-summary.results[ , 4:5] <- round(summary.results[ , 4:5], 1)
-summary.results[ , 6] <- round(summary.results[ , 6], 4)
+summary.results[ , 4:7] <- round(summary.results[ , 4:7], 1)
+summary.results[ , 8] <- round(summary.results[ , 8], 4)
 
 
 
