@@ -150,7 +150,6 @@ samples.deviance <- array(NA, c(n.keep, 1))
 samples.fitted <- array(NA, c(n.keep, n))
 
 ## Metropolis quantities
-tau2.posterior.shape <- prior.tau2[1] + 0.5*(n-1)
 nu2.posterior.shape <- prior.nu2[1] + 0.5*n
      
 
@@ -162,6 +161,7 @@ nu2.posterior.shape <- prior.nu2[1] + 0.5*n
     if(!is.numeric(W)) stop("W has non-numeric values.", call.=FALSE)
     if(min(W)<0) stop("W has negative elements.", call.=FALSE)
     if(sum(W!=t(W))>0) stop("W is not symmetric.", call.=FALSE)
+    if(min(apply(W, 1, sum))==0) stop("W has some areas with no neighbours (one of the row sums equals zero).", call.=FALSE)    
 
 ## Create the triplet object
 W.triplet <- c(NA, NA, NA)
@@ -194,8 +194,6 @@ temp <- 1
 
 #### Beta update quantities
 data.precision.beta <- t(X.standardised) %*% X.standardised
-data.var.beta <- solve(data.precision.beta)
-data.temp.beta <- data.var.beta %*% t(X.standardised)
 	if(length(prior.var.beta)==1)
 	{
 	prior.precision.beta <- 1 / prior.var.beta
@@ -205,6 +203,16 @@ data.temp.beta <- data.var.beta %*% t(X.standardised)
 	}
 
 
+## Check for islands
+W.list<- mat2listw(W)
+W.nb <- W.list$neighbours
+W.islands <- n.comp.nb(W.nb)
+islands <- W.islands$comp.id
+n.islands <- max(W.islands$nc)
+tau2.posterior.shape <- prior.tau2[1] + 0.5 * (n-n.islands)   
+
+
+
 
 ###########################
 #### Run the Bayesian model
@@ -225,13 +233,15 @@ data.temp.beta <- data.var.beta %*% t(X.standardised)
     ####################
     ## Sample from beta
     ####################
-    data.mean.beta <- data.temp.beta %*% (Y - phi - offset)
-    U <- chol((prior.precision.beta + data.precision.beta / nu2))
-    Uinv <- backsolve(U, diag(rep(1,p)))
-    fc.mean.beta <- Uinv %*% (t(Uinv) %*% (prior.precision.beta %*% prior.mean.beta + (data.precision.beta / nu2) %*% data.mean.beta))
-    beta <- fc.mean.beta + Uinv %*% rnorm(p)
-
-      
+    fc.precision <- prior.precision.beta + data.precision.beta / nu2
+    fc.var <- solve(fc.precision)
+    beta.offset <- as.numeric(Y - offset - phi)
+    beta.offset2 <- t(X.standardised) %*% beta.offset / nu2 + prior.precision.beta %*% prior.mean.beta
+    fc.mean <- fc.var %*% beta.offset2
+    chol.var <- t(chol(fc.var))
+    beta <- fc.mean + chol.var %*% rnorm(p)  
+    
+    
     
     ##################
     ## Sample from nu2
@@ -246,7 +256,11 @@ data.temp.beta <- data.var.beta %*% t(X.standardised)
     ####################
     offset.phi <- (Y - as.numeric(X.standardised %*% beta) - offset) / nu2    
     phi <- gaussiancarupdate(Wtriplet=W.triplet, Wbegfin=W.begfin, W.triplet.sum, nsites=n, phi=phi, tau2=tau2, rho=1, nu2=nu2, offset=offset.phi)
-    phi <- phi - mean(phi)
+    for(i in 1:n.islands)
+    {
+        phi[which(islands==i)] <- phi[which(islands==i)] - mean(phi[which(islands==i)])    
+    }
+    
     
     
 
@@ -327,7 +341,7 @@ DIC <- 2 * median(samples.deviance) - deviance.fitted
 CPO <- rep(NA, n)
      for(j in 1:n)
      {
-     CPO[j] <- 1/median((1 / dnorm(Y[j], mean=samples.fitted[ ,j], sd=samples.nu2)))    
+     CPO[j] <- 1/median((1 / dnorm(Y[j], mean=samples.fitted[ ,j], sd=sqrt(samples.nu2))))   
      }
 LMPL <- sum(log(CPO))       
 
@@ -365,20 +379,20 @@ if(number.cts>0)
 #### Create a summary object
 samples.beta.orig <- mcmc(samples.beta.orig)
 summary.beta <- t(apply(samples.beta.orig, 2, quantile, c(0.5, 0.025, 0.975))) 
-summary.beta <- cbind(summary.beta, rep(n.keep, p), rep(100, p))
+summary.beta <- cbind(summary.beta, rep(n.keep, p), rep(100,p), effectiveSize(samples.beta.orig), geweke.diag(samples.beta.orig)$z)
 rownames(summary.beta) <- colnames(X)
-colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept")
+colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
 
-summary.hyper <- array(NA, c(2 ,5))
+summary.hyper <- array(NA, c(2 ,7))
 summary.hyper[1, 1:3] <- quantile(samples.nu2, c(0.5, 0.025, 0.975))
-summary.hyper[1, 4:5] <- c(n.keep, 100)
+summary.hyper[1, 4:7] <- c(n.keep, 100, effectiveSize(samples.nu2), geweke.diag(samples.nu2)$z)
 summary.hyper[2, 1:3] <- quantile(samples.tau2, c(0.5, 0.025, 0.975))
-summary.hyper[2, 4:5] <- c(n.keep, 100)
+summary.hyper[2, 4:7] <- c(n.keep, 100, effectiveSize(samples.tau2), geweke.diag(samples.tau2)$z)
 
 summary.results <- rbind(summary.beta, summary.hyper)
 rownames(summary.results)[(nrow(summary.results)-1):nrow(summary.results)] <- c("nu2", "tau2")
 summary.results[ , 1:3] <- round(summary.results[ , 1:3], 4)
-summary.results[ , 4:5] <- round(summary.results[ , 4:5], 1)
+summary.results[ , 4:7] <- round(summary.results[ , 4:7], 1)
 
 
 #### Create the Fitted values and residuals
