@@ -1,13 +1,13 @@
 ### R code from vignette source 'CARBayesvignette.Rnw'
 
 ###################################################
-### code chunk number 1: CARBayesvignette.Rnw:194-195
+### code chunk number 1: CARBayesvignette.Rnw:193-194
 ###################################################
 library(CARBayes)
 
 
 ###################################################
-### code chunk number 2: CARBayesvignette.Rnw:200-204
+### code chunk number 2: CARBayesvignette.Rnw:199-203
 ###################################################
 library(shapefiles)
 library(sp)
@@ -16,13 +16,13 @@ library(spdep)
 
 
 ###################################################
-### code chunk number 3: CARBayesvignette.Rnw:209-210
+### code chunk number 3: CARBayesvignette.Rnw:240-241
 ###################################################
 library(CARBayesdata)
 
 
 ###################################################
-### code chunk number 4: CARBayesvignette.Rnw:246-249
+### code chunk number 4: CARBayesvignette.Rnw:247-250
 ###################################################
 data(lipdata)
 data(lipdbf)
@@ -30,28 +30,28 @@ data(lipshp)
 
 
 ###################################################
-### code chunk number 5: CARBayesvignette.Rnw:254-256
+### code chunk number 5: CARBayesvignette.Rnw:255-257
 ###################################################
 lipdbf$dbf <- lipdbf$dbf[ ,c(2,1)]
 data.combined <- combine.data.shapefile(data=lipdata, shp=lipshp, dbf=lipdbf)
 
 
 ###################################################
-### code chunk number 6: CARBayesvignette.Rnw:262-264
+### code chunk number 6: CARBayesvignette.Rnw:263-265
 ###################################################
 W.nb <- poly2nb(data.combined, row.names = rownames(lipdata))
 W.mat <- nb2mat(W.nb, style="B")
 
 
 ###################################################
-### code chunk number 7: CARBayesvignette.Rnw:281-283
+### code chunk number 7: CARBayesvignette.Rnw:282-284
 ###################################################
 data(propertydata.spatial)
 propertydata <- propertydata.spatial@data
 
 
 ###################################################
-### code chunk number 8: CARBayesvignette.Rnw:327-336
+### code chunk number 8: CARBayesvignette.Rnw:328-337
 ###################################################
 northarrow <- list("SpatialPolygonsRescale", layout.north.arrow(), offset = c(220000,647000), 
 scale = 4000)
@@ -65,14 +65,14 @@ col.regions=hsv(0,seq(0.05,1,length.out=7),1), col="transparent")
 
 
 ###################################################
-### code chunk number 9: CARBayesvignette.Rnw:351-353
+### code chunk number 9: CARBayesvignette.Rnw:352-354
 ###################################################
 propertydata$logprice <- log(propertydata$price)
 propertydata$logdriveshop <- log(propertydata$driveshop)
 
 
 ###################################################
-### code chunk number 10: CARBayesvignette.Rnw:358-361
+### code chunk number 10: CARBayesvignette.Rnw:359-362
 ###################################################
 library(splines)
 form <- logprice~ns(crime,3)+rooms+sales+factor(type) + logdriveshop
@@ -80,16 +80,17 @@ model <- lm(formula=form, data=propertydata)
 
 
 ###################################################
-### code chunk number 11: CARBayesvignette.Rnw:369-373
+### code chunk number 11: CARBayesvignette.Rnw:370-375
 ###################################################
 W.nb <- poly2nb(propertydata.spatial, row.names = rownames(propertydata))
 W.list <- nb2listw(W.nb, style="B")
+library(spdep)
 resid.model <- residuals(model)
 moran.mc(x=resid.model, listw=W.list, nsim=1000)
 
 
 ###################################################
-### code chunk number 12: CARBayesvignette.Rnw:394-397
+### code chunk number 12: CARBayesvignette.Rnw:388-391
 ###################################################
 W.mat <- nb2mat(W.nb, style="B")
 model.spatial <- S.CARleroux(formula=form, data=propertydata, family="gaussian", 
@@ -97,44 +98,43 @@ W=W.mat, burnin=1000, n.sample=2000, verbose=FALSE)
 
 
 ###################################################
-### code chunk number 13: CARBayesvignette.Rnw:406-407
+### code chunk number 13: CARBayesvignette.Rnw:408-409
 ###################################################
 summary(model.spatial)
 
 
 ###################################################
-### code chunk number 14: CARBayesvignette.Rnw:417-418
+### code chunk number 14: CARBayesvignette.Rnw:419-420
 ###################################################
 summarise.samples(model.spatial$samples$beta, quantiles=c(0.5, 0.025, 0.975))
 
 
 ###################################################
-### code chunk number 15: CARBayesvignette.Rnw:423-425
+### code chunk number 15: CARBayesvignette.Rnw:425-427
 ###################################################
 crime.effect <- summarise.lincomb(model=model.spatial, columns=c(2,3,4), 
 quantiles=c(0.5, 0.025, 0.975), distribution=FALSE)
 
 
 ###################################################
-### code chunk number 16: CARBayesvignette.Rnw:445-450
+### code chunk number 16: CARBayesvignette.Rnw:445-448
 ###################################################
-ord <- order(propertydata$crime)
-plot(propertydata$crime[ord], crime.effect$quantiles[ord ,1], pch=19, ylim=c(-0.55,0.05), xlab="Crime rate", ylab="Effect of crime", type="l")
-rug(propertydata$crime)
-lines(propertydata$crime[ord], crime.effect$quantiles[ord ,2], pch=19, col="red")
-lines(propertydata$crime[ord], crime.effect$quantiles[ord ,3], pch=19, col="red")
+plot(propertydata$crime, crime.effect$quantiles[ ,1], pch=19, ylim=c(-0.55,0.05), xlab="Crime rate", ylab="Effect of crime")
+points(propertydata$crime, crime.effect$quantiles[ ,2], pch=19, col="red")
+points(propertydata$crime, crime.effect$quantiles[ ,3], pch=19, col="red")
 
 
 ###################################################
-### code chunk number 17: CARBayesvignette.Rnw:476-479
+### code chunk number 17: CARBayesvignette.Rnw:474-478
 ###################################################
+library(CARBayesdata)
 data(respiratorydata.spatial)
 respiratorydata <- respiratorydata.spatial@data
 head(respiratorydata)
 
 
 ###################################################
-### code chunk number 18: CARBayesvignette.Rnw:485-489
+### code chunk number 18: CARBayesvignette.Rnw:484-488
 ###################################################
 respiratorydata$SIR2010 <- respiratorydata$observed2010 / respiratorydata$expected2010
 respiratorydata.spatial@data$SIR2010 <- respiratorydata$SIR2010
@@ -143,7 +143,7 @@ W.mat <- nb2mat(W.nb, style="B")
 
 
 ###################################################
-### code chunk number 19: CARBayesvignette.Rnw:497-504
+### code chunk number 19: CARBayesvignette.Rnw:496-503
 ###################################################
 northarrow <- list("SpatialPolygonsRescale", layout.north.arrow(), offset = c(220000,647000), scale = 4000)
 scalebar <- list("SpatialPolygonsRescale", layout.scale.bar(), offset = c(225000,647000), scale = 10000, fill=c("transparent","black"))
@@ -155,10 +155,9 @@ spplot(respiratorydata.spatial, c("SIR2010"), sp.layout=list(northarrow, scaleba
 
 
 ###################################################
-### code chunk number 20: CARBayesvignette.Rnw:523-526
+### code chunk number 20: CARBayesvignette.Rnw:522-524
 ###################################################
 Z.incomedep <- as.matrix(dist(cbind(respiratorydata$incomedep2010, 
-respiratorydata$incomedep2010), method="manhattan", diag=TRUE, upper=TRUE)) * 
-W.mat / 2
+respiratorydata$incomedep2010), method="manhattan", diag=TRUE, upper=TRUE)) * W.mat / 2
 
 
